*******************************************************************************
*******************************************************************************
***	 Replication Package for "Regional Resources and Democratic Secessionism***
***  Last Update : September 2019                                           ***
***  Author      : Stephan A. Schneider, Kai Gehring                        ***
***  Requires    : combined_data_cleaned3.dta                               ***
***                data_final_extended.dta                                  ***
***                oilgraphic.dta                                           ***
*******************************************************************************
*******************************************************************************

*Please proceed with the following steps in order to reproduce the results from the paper.
*1) Extract all files to a common folder.
*2) Make sure the folder contains the following subfolders: "do-files" (This folder contains the do-files), "Stata" (this folder contains the datasets)
*3) Set your path to the "Stata"-folder containing the datasets in line 31 of this do-file (e.g., local DIR="C:\Users\...\Stata") 
*4) Run this do-file. You have to run the whole file including all locals and globals to replicate the results. The beginning of the code automatically loads external packages that are not native to Stata. Sub-do-files must remain in the same folder. 
*5) The code will automatically create sub-folders for tables and graphics, in which the results will be stored.

*********************************Set*file*path*********************************

drop _all
clear matrix
clear mata
*version 12
set more off
set matsize 6000 
set maxvar 30000
set seed 100

*SET FILE PATH
local DIR = "C:\Users\...\Stata" //Insert file path in this line.
cap cd "`DIR'" 

***********************************************************************************
set more off,perm

*** Create folders "data processed"(where transformed data are stored) and "tables" (where tables are stored)
program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"data processed"'	  	/* does folder "bearbeitet" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "data processed"  	/* makes the folder  */
							  } 
			  else {
				di "folder data processed already exists"
				}
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
					confirmdir `"graphics"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "graphics"  /* makes the folder  */
							  } 
			  else {
				di "folder graphics already exists"
				}
program drop confirmdir

cap net install coefplot.pkg
cap ssc install moremata
cap ssc install ivreg2
cap ssc install xtivreg2
cap ssc install reghdfe
cap ssc install ranktest
cap ssc install carryforward
cap ssc install estout				

do "..\Do-Files\WildClusterBootstrap_rep.do"
 
*Note:
// The warning message "Warning: estimated covariance matrix of moment conditions not of full rank..." displayed does only concern the validty of the overall F-test, 
// which is not our focus. The interpretation of individual coefficients and marginal effects is still valid. Please disregard the message for that reason. 
 
********************
*Descriptive Figures
********************

*Figure2

use "oilgraphic.dta", clear

twoway  (scatter  Numgiantoildisc NumOildisc year, yaxis(1)  msymbol( dot dot ) msize(medlarge medsmall) mcolor("255 147 127" "14 61 136")) ///
(line brentprice2001_avg year, yaxis(2) ylabel(0(20)100, axis(2))  lpattern(shortdash) lcolor(gs11) ) , ///
ytitle("Count", margin( small ))  ///
   xtitle("Year", margin( small ))  xlabel (1950 1960 1970 1980  1990  2000) ytick(1 2 3 4 5 6 7 8 9 10) xtick( 1945 1950 1955 1960 1965 1970 1975 1980 1985 1990 1995 2000) ///
   legend(   label( 1  "Number of giant oil discoveries") label(2 "Number of oil discoveries" ) label(3 "Oil price (constant 2001 USD)" ) region(col(white)) ) ///
   graphregion(color(white))  ysize(3.6) 
 graph export     "graphics\Figure2.png",width(4000) replace 
window manage  close graph _all	 


*Figure 3

use "data_final_extended.dta", clear
xtset constituency_id hyear

bysort hyear: egen SNPavg = mean(nationalistvoteshare100) if country_name == "Scotland" & byelection == 0
bysort hyear: egen PCavg = mean(nationalistvoteshare100) if country_name == "Wales" & byelection == 0

gen SNPshare = nationalistvoteshare100 if country_name=="Scotland" 
gen PCshare = nationalistvoteshare100 if country_name=="Wales"

bysort hyear: egen PCavg2 = mean(PCavg) if byelection == 0
bysort hyear: egen SNPavg2 = mean(SNPavg) if byelection == 0

scatter PCshare SNPshare  PCavg2 SNPavg2  hyear ///
, msymbol(dot dot) msize(vsmall vsmall )  mcolor("255 207 195"  "89 122 173"  "255 147 127"  "14 61 136") yline(0 10 20 30 40 50 60, lwidth( thin ) lcolor(gs13))  xlabel(-30(20)80) ylabel(0(10)65) xtick(-30(20)80) xmtick(-30(10)80) ytick(0(5)65)   graphregion(color(white)) ///
|| lfit PCshare hyear if year < 1970, lcolor("255 147 127") lpattern(dash) ///
|| lfit SNPshare hyear if year < 1970, lcolor("14 61 136") lpattern(dash) legend(region(col(white))   label( 1  "Plaid Cymru") label(2 "SNP" ) label( 3  "Plaid Cymru (avg in GE)") label(4 "SNP (avg in GE)" ) label( 5  "Pre-Trend Plaid Cymru") label(6 "Pre-Trend SNP" )  ) ///
xlabel(-20 "1950" 0  "1960" 20 "1970" 40 "1980" 60 "1990" 80 "2000"  ) xtitle("Year")
graph export "graphics\Figure3.png",width(2222) replace
window manage  close graph _all	 


use "data_final_extended.dta", clear
sort country_name constituencyname hyear
xtset constituency_id hyear

gen countf=.
replace countf=_n-10
gen coeff=.
gen ciuf=.
gen cilf=.
replace countf=. if countf>8
replace countf=. if countf<-8


*Figure 4
*Fill up observations (last election result) for graphic requested by the editor/referees
sort constituencyname hyear
gen nationalistvoteshare100_b=.
 replace nationalistvoteshare100_b=nationalistvoteshare100
 by constituencyname: replace nationalistvoteshare100_b=nationalistvoteshare100_b[_n-1] if nationalistvoteshare100_b==.
 by constituencyname: replace scot=scot[_n-1] if scot==.

xtset constituency_id hyear

quietly{
ivreg2 nationalistvoteshare100_b scot hy_* c.f16.Nod_t1t_sum##c.scot, cluster(constituencyname year) 
replace coeff=_b[cF16.Nod_t1t_sum#c.scot ] if countf==-4
replace ciuf=_b[cF16.Nod_t1t_sum#c.scot ] + _se[cF16.Nod_t1t_sum#c.scot ]*1.96 if countf==-4
replace cilf=_b[cF16.Nod_t1t_sum#c.scot ] - _se[cF16.Nod_t1t_sum#c.scot ]*1.96 if countf==-4
ivreg2 nationalistvoteshare100_b scot hy_* c.f12.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cF12.Nod_t1t_sum#c.scot ] if countf==-3
replace ciuf=_b[cF12.Nod_t1t_sum#c.scot ] + _se[cF12.Nod_t1t_sum#c.scot ]*1.96 if countf==-3
replace cilf=_b[cF12.Nod_t1t_sum#c.scot ] - _se[cF12.Nod_t1t_sum#c.scot ]*1.96 if countf==-3
ivreg2 nationalistvoteshare100_b scot hy_* c.f8.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cF8.Nod_t1t_sum#c.scot ] if countf==-2
replace ciuf=_b[cF8.Nod_t1t_sum#c.scot ] + _se[cF8.Nod_t1t_sum#c.scot ]*1.96 if countf==-2
replace cilf=_b[cF8.Nod_t1t_sum#c.scot ] - _se[cF8.Nod_t1t_sum#c.scot ]*1.96 if countf==-2
ivreg2 nationalistvoteshare100_b scot hy_* c.f4.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cF4.Nod_t1t_sum#c.scot ] if countf==-1
replace ciuf=_b[cF4.Nod_t1t_sum#c.scot ] + _se[cF4.Nod_t1t_sum#c.scot ]*1.96 if countf==-1
replace cilf=_b[cF4.Nod_t1t_sum#c.scot ] - _se[cF4.Nod_t1t_sum#c.scot ]*1.96 if countf==-1
ivreg2 nationalistvoteshare100_b scot hy_* c.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[c.Nod_t1t_sum#c.scot ] if countf==0
replace ciuf=_b[c.Nod_t1t_sum#c.scot ] + _se[c.Nod_t1t_sum#c.scot ]*1.96 if countf==0
replace cilf=_b[c.Nod_t1t_sum#c.scot ] - _se[c.Nod_t1t_sum#c.scot ]*1.96 if countf==0
ivreg2 nationalistvoteshare100_b scot hy_* c.l4.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cL4.Nod_t1t_sum#c.scot ] if countf==1
replace ciuf=_b[cL4.Nod_t1t_sum#c.scot ] + _se[cL4.Nod_t1t_sum#c.scot ]*1.96 if countf==1
replace cilf=_b[cL4.Nod_t1t_sum#c.scot ] - _se[cL4.Nod_t1t_sum#c.scot ]*1.96 if countf==1
ivreg2 nationalistvoteshare100_b scot hy_* c.l8.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cL8.Nod_t1t_sum#c.scot ] if countf==2
replace ciuf=_b[cL8.Nod_t1t_sum#c.scot ] + _se[cL8.Nod_t1t_sum#c.scot ]*1.96 if countf==2
replace cilf=_b[cL8.Nod_t1t_sum#c.scot ] - _se[cL8.Nod_t1t_sum#c.scot ]*1.96 if countf==2
ivreg2 nationalistvoteshare100_b scot hy_* c.l12.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cL12.Nod_t1t_sum#c.scot ] if countf==3
replace ciuf=_b[cL12.Nod_t1t_sum#c.scot ] + _se[cL12.Nod_t1t_sum#c.scot ]*1.96 if countf==3
replace cilf=_b[cL12.Nod_t1t_sum#c.scot ] - _se[cL12.Nod_t1t_sum#c.scot ]*1.96 if countf==3
ivreg2 nationalistvoteshare100_b scot hy_* c.l16.Nod_t1t_sum##c.scot, cluster(constituencyname year)
replace coeff=_b[cL16.Nod_t1t_sum#c.scot ] if countf==4
replace ciuf=_b[cL16.Nod_t1t_sum#c.scot ] + _se[cL16.Nod_t1t_sum#c.scot ]*1.96 if countf==4
replace cilf=_b[cL16.Nod_t1t_sum#c.scot ] - _se[cL16.Nod_t1t_sum#c.scot ]*1.96 if countf==4
}

 twoway rcap  ciuf cilf countf if countf>-5 & countf<5 , lcolor(gs8) msize(medlarge) lwidth(medium)  ||  ///
 line  coeff countf if countf>-5 & countf<5 , lcolor(gs0) lwidth( medthick ) lpattern(dot) ///  
 || scatter coeff  countf if countf>-5 & countf<5 ///
, msymbol(dot dot) msize(small small )  mcolor("14 61 136" "255 147 127") yline(-1 0 1 2 , lwidth( thin ) lcolor(gs13))  ///
  yline( -1 1 2 , lwidth( thin ) lcolor(gs13))  ylabel(-1 0 1 2 ) yline(0, lwidth( thin) lcolor(gs0))  ///  
   xlabel(-4(1)4) xtick(-4(1)4)  yscale(range(-1.15 2.5)) /// 
 graphregion(color(white))  xtick(-4(1)4) xlabel(-4 "-4" -3 "-3" -2 "-2" -1 "-1" 0 "t" 1 "1" 2 "2" 3 "3" 4 "4" ) ///      
 graphregion(color(white))  xline(-0.5, lwidth( med ) lcolor(gs8) lpattern(dash) ) ytitle("Coefficient of Discoveries x Scotland") legend(off) xtitle("Leads                    Timing of Discovery                      Lags"  )  ///
 ysize(3.7)

 graph export     "graphics\Figure4.png",width(4000) replace 
window manage  close graph _all	 



*************************************Analysis*************************************************
use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear

********************
global controls unemploymentrate gdp100
global post1970int oilexistsXscotXhy_1970_1-oilexistsXscotXhy_2000_2 
*list $post1970
global timeinvariantcontrols border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff ra_wheat_int_rf_resample ra_wheat_int_irr_resample ra_potato_int_rf_resample ra_potato_int_irr_resample ///
ra_barley_int_rf_resample ra_barley_int_irr_resample
global timeinvariantcontrols_short border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff 

*Table2
*Summary Statistics
format %9.3f nationalistvoteshare100 Ngod_t1t_sum Nod_t1t_sum mRd_t1t_sum scot brentprice2001_avg annualproductionb unemploymentrate gdp100  nearborder50 nearborder75 nearborder100 seaside dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga

sum nationalistvoteshare100 Ngod_t1t_sum Nod_t0t_sum mRd_t1t_sum scot brentprice2001_avg  unemploymentrate gdp100 nearborder50 nearborder75 nearborder100 seaside dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga,format

matrix input A=(0, 0, 0, 0 ,0 \ 0, 0 ,0,0,0  \0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0\ 0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0)

local no=1
foreach var in nationalistvoteshare100 Ngod_t1t_sum Nod_t0t_sum  scot brentprice2001_avg annualproductionb unemploymentrate gdp100{    
sum `var' if nationalistvoteshare != .
local obs=r(N)

local mean=r(mean)
local sd=r(sd)
local min=r(min)
local max=r(max)

matrix A[`no',1]=`obs'
matrix A[`no',2]=`mean'
matrix A[`no',3]=`sd'
matrix A[`no',4]=`min'
matrix A[`no',5]=`max'

local no=`no'+1
}
	

matrix rownames A = "Secessionist vote share" "Discoveries (giant)" "Discoveries (all)"  "Scotland" "Oil price" "Oil production" "Unemployment rate" "GDP per capita" //  
matrix colnames A=Obs Mean SD Min Max
mat list A

estout matrix(A, fmt(0 2 2 2 2 ) )using "tables\Table2.txt",replace   ///
style(tab) delimiter(_tab ) title(Descriptives) 

**************************************************
*TABLE 3
**************************************************
estimates drop _all

eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)



estout est2* using "tables\Table3.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum $controls ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  $controls ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )

**************************************************
*TABLE 4
**************************************************
*For graphic
cap noisily drop CountG CumCof CumCof_cu CumCof_cl
gen CountG = .
replace CountG =_n if _n<=4
gen CumCof = .
gen CumCof_cu=.
gen CumCof_cl=.

*Table4
estimates drop _all

eststo est3A: ivreg2 nationalistvoteshare100 hy_* i.constituency_id c.Ngod_t1t_sum##scot $controls  tt_scot i.constituency_id ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t1t_sum] if CountG==1
replace CumCof_cu =_b[1.scot#c.Ngod_t1t_sum] +_se[1.scot#c.Ngod_t1t_sum]*1.96 if CountG==1
replace CumCof_cl =_b[1.scot#c.Ngod_t1t_sum] -_se[1.scot#c.Ngod_t1t_sum]*1.96 if CountG==1
eststo est3B: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t2t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t2t_sum] if CountG==2
replace CumCof_cu =_b[1.scot#c.Ngod_t2t_sum] +_se[1.scot#c.Ngod_t2t_sum]*1.96 if CountG==2
replace CumCof_cl =_b[1.scot#c.Ngod_t2t_sum] -_se[1.scot#c.Ngod_t2t_sum]*1.96 if CountG==2
eststo est3C: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t3t_sum##scot $controls hy_* tt_scot i.constituency_id ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t3t_sum]  if CountG==3
replace CumCof_cu =_b[1.scot#c.Ngod_t3t_sum] +_se[1.scot#c.Ngod_t3t_sum]*1.96 if CountG==3
replace CumCof_cl =_b[1.scot#c.Ngod_t3t_sum] -_se[1.scot#c.Ngod_t3t_sum]*1.96 if CountG==3
eststo est3D: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t4t_sum##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t4t_sum] if CountG==4
replace CumCof_cu =_b[1.scot#c.Ngod_t4t_sum] +_se[1.scot#c.Ngod_t4t_sum]*1.96 if CountG==4
replace CumCof_cl =_b[1.scot#c.Ngod_t4t_sum] -_se[1.scot#c.Ngod_t4t_sum]*1.96 if CountG==4


eststo est3F: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t1t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t1t_py] if CountG==1
replace CumCof_cu =_b[1.scot#c.Ngod_t1t_py] +_se[1.scot#c.Ngod_t1t_py]*1.96 if CountG==1
replace CumCof_cl =_b[1.scot#c.Ngod_t1t_py] -_se[1.scot#c.Ngod_t1t_py]*1.96 if CountG==1
eststo est3G: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t2t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t2t_py] if CountG==2
replace CumCof_cu =_b[1.scot#c.Ngod_t2t_py] +_se[1.scot#c.Ngod_t2t_py]*1.96 if CountG==2
replace CumCof_cl =_b[1.scot#c.Ngod_t2t_py] -_se[1.scot#c.Ngod_t2t_py]*1.96 if CountG==2
eststo est3H: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t3t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t3t_py] if CountG==3
replace CumCof_cu =_b[1.scot#c.Ngod_t3t_py] +_se[1.scot#c.Ngod_t3t_py]*1.96 if CountG==3
replace CumCof_cl =_b[1.scot#c.Ngod_t3t_py] -_se[1.scot#c.Ngod_t3t_py]*1.96 if CountG==3
eststo est3I: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t4t_py##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
replace CumCof =_b[1.scot#c.Ngod_t4t_py] if CountG==4
replace CumCof_cu =_b[1.scot#c.Ngod_t4t_py] +_se[1.scot#c.Ngod_t4t_py]*1.96 if CountG==4
replace CumCof_cl =_b[1.scot#c.Ngod_t4t_py] -_se[1.scot#c.Ngod_t4t_py]*1.96 if CountG==4

estout est3* using "tables\Table4.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum     1.scot#c.Ngod_t1t_py  1.scot#c.Ngod_t2t_py    1.scot#c.Ngod_t3t_py ///
	1.scot#c.Ngod_t4t_py    ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum    1.scot#c.Ngod_t1t_py  1.scot#c.Ngod_t2t_py    1.scot#c.Ngod_t3t_py ///
	1.scot#c.Ngod_t4t_py     ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )


twoway  (line  CumCof CumCof_cu CumCof_cl CountG,  lwidth(vthin) color(gs14 gs14 gs14)   ytick(-1 (1) 1, gstyle(major)) graphregion(color(white)) ) ///
(line CumCof CumCof_cu CumCof_cl CountG, lwidth(medthin) lpattern(solid dash dash) color(black black black))  (scatter CumCof CumCof_cu CumCof_cl CountG,  msymbol( square  ) msize(medlarge) color("89 122 173"   "14 61 136"   "14 61 136"  ))  , ///
 yline(0, lwidth( medsmall ) lcolor(black) )  yline(-2    2 4 6 8 10 12 , lwidth( vvvthin ) lcolor(gs5)) legend(off) ///
  yscale(range(-1 12)) xlabel(1 2 3 4 ) ylabel(-2 0  2 4 6 8 10 12, ticks tlwidth(vthin ) nogrid) ytitle (Coefficient of the avg of Oil Discoveries (giant)_t) 
graph export "graphics\FigureA10.png",width(4000) replace
window manage  close graph _all	 



estimates drop _all

eststo est4A: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t1t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4B: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id  c.Nod_t2t_sum##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4C: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t3t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4D: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id  c.Nod_t4t_sum##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4F: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t1t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4G: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t2t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4H: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t3t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est4I: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id  c.Nod_t4t_py##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)


estout est4* using "tables\Table4.txt", ///
	append title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Nod_t1t_sum   1.scot#c.Nod_t1t_sum  1.scot#c.Nod_t2t_sum   1.scot#c.Nod_t3t_sum   ///
	1.scot#c.Nod_t4t_sum    1.scot#c.Nod_t1t_py  1.scot#c.Nod_t2t_py    1.scot#c.Nod_t3t_py ///
	1.scot#c.Nod_t4t_py    ) ///
	order( 1.scot#c.Nod_t1t_sum  1.scot#c.Nod_t2t_sum    1.scot#c.Nod_t3t_sum ///
	1.scot#c.Nod_t4t_sum     1.scot#c.Nod_t1t_py  1.scot#c.Nod_t2t_py    1.scot#c.Nod_t3t_py ///
	1.scot#c.Nod_t4t_py    ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
	


	
*Table5
gen annualvaluescot_gdpshare100=annualvaluescot_gdpshare*100
label variable annualvaluescot_gdpshare100 "Oil prod. value / Onshore GDP (Percent)"
label variable annualproductionb "Oil production"
replace annualvaluescot_gdpshare100=0 if annualvaluescot_gdpshare100==.
eststo estT5N1: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls c.annualproductionb##scot  ,cluster (constituencyname hyear)
eststo estT5N2: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls c.annualproductionb##scot c.Ngod_t1t_sum##scot ,cluster (constituencyname hyear)
eststo estT5N3: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls c.annualvaluescot##scot  ,cluster (constituencyname hyear)
eststo estT5N4: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls c.annualvaluescot##scot c.Ngod_t1t_sum##scot ,cluster (constituencyname hyear)
eststo estT5N5: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls  c.annualvaluescot_gdpshare100##scot  ,cluster (constituencyname hyear)
eststo estT5N6: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id tt_scot $controls  c.annualvaluescot_gdpshare100##scot c.Ngod_t1t_sum##scot ,cluster (constituencyname hyear) 

estout estT5N* using "tables\Table5.txt", ///
	replace title("no byelections") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par([ ]) vacant("") label(p-value))) style(tab) delimiter(_tab )  ///
	stats(  N, labels(  "Number of Observations") fmt(  0 3 3))  ///
	order( 1.scot#c.Ngod_t1t_sum     ) ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot#c.annualproductionb  1.scot#c.annualvaluescot 1.scot#c.annualvaluescot_gdpshare100 ) 
	
	

	
 
***********************************Table 6 ************************************* 
********************************Interactions************************************
use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear

********************
global controls unemploymentrate gdp100
global post1970int oilexistsXscotXhy_1970_1-oilexistsXscotXhy_2000_2 
global timeinvariantcontrols border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff ra_wheat_int_rf_resample ra_wheat_int_irr_resample ra_potato_int_rf_resample ra_potato_int_irr_resample ///
ra_barley_int_rf_resample ra_barley_int_irr_resample
global timeinvariantcontrols_short border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff 
gen hyear2 = hyear + 31 
sort country_name constituencyname hyear
gen landlocked = 0
replace landlocked= 1 if seaside==0

forvalues i=1(1)7 {
local j=10*`i'
gen Ddecade_`i'=0
replace Ddecade_`i'=1 if year>=1930+`j' & year<(1940+`j')
gen Ddecadescot`i'=Ddecade_`i'*scot
}

*Initial share
cap drop  av_nationlistvoteshare100_60s
cap drop  t_av_nationlistvoteshare100_60s
bys Ddecade_3 constituency_id: egen t_av_nationlistvoteshare100_60s= mean(nationalistvoteshare100)
replace   t_av_nationlistvoteshare100_60s=. if Ddecade_3==0
bys constituency_id: egen av_nationlistvoteshare100_60s=mean(t_av_nationlistvoteshare100_60s)

cap drop  av_nationlistvoteshare100_50s
cap drop  t_av_nationlistvoteshare100_50s
bys Ddecade_2 constituency_id: egen t_av_nationlistvoteshare100_50s= mean(nationalistvoteshare100)
replace   t_av_nationlistvoteshare100_50s=. if Ddecade_2==0
bys constituency_id: egen av_nationlistvoteshare100_50s=mean(t_av_nationlistvoteshare100_50s)

gen av_nationlistvoteshare100_50a60s= (av_nationlistvoteshare100_50s+av_nationlistvoteshare100_60s)/2
ren av_nationlistvoteshare100_50a60s av_nvoteshare5060

local inter_ext rel_englRES rel_parnonRES   rel_industry rel_agriculture rel_government  rel_whitecollar av_nvoteshare5060 ///
rel_edutermU15ALLED1951 rel_eduterm20UPALLED1951 rel_educationRES rel_uniRES  dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga rel_englPOP 

*Interactions: standardize
foreach var in `inter_ext'{
cap drop X_`var'
clonevar X_`var'=`var'
drop `var'
egen `var'=std(X_`var'), mean(0)
}
 
*Heterogeneous effects
local inter_basic   nearborder50 nearborder75 nearborder100  landlocked dist_d_Aberdeen

cap estimates drop _all	
foreach var in `inter_basic' { 
cap drop inter
gen inter=`var'
eststo : ivreg2 nationalistvoteshare100 hy_* tt_scot i.hyear2##c.inter i.constituency_id c.Ngod_t1t_sum##c.scot##c.inter  $controls ,cluster (constituencyname hyear)
}

 estout est* using "tables\Table6.txt", ///
	replace  title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )  ///
	stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(c.Ngod_t1t_sum#c.scot   c.Ngod_t1t_sum#c.scot#c.inter ) ///
	 indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
  
local inter_ext  rel_englRES av_nvoteshare5060 rel_edutermU15ALLED1951 rel_educationRES rel_whitecollar
 quietly { 
cap estimates drop _all	
foreach var in `inter_ext' { 
cap drop inter
gen inter=`var'
eststo : ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id i.hyear2##c.inter c.Ngod_t1t_sum##c.scot##c.inter   $controls ,cluster (constituencyname hyear)
}
}
estout est* using "tables\Table6.txt", ///
	append title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )  ///
	stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(c.Ngod_t1t_sum#c.scot c.Ngod_t1t_sum#c.scot#c.inter  ) ///
	 indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
	 
local inter_ext   rel_government  rel_industry rel_agriculture  av_soilsuitability ra_ruggedness_index_nunn_puga    //  
 quietly { 
cap estimates drop _all	
foreach var in `inter_ext' { 
cap drop inter
gen inter=`var'
eststo : ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id i.hyear2##c.inter c.Ngod_t1t_sum##c.scot##c.inter   $controls ,cluster (constituencyname hyear)
}
}
estout est* using "tables\Table6.txt", ///
	append title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )  ///
	stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(c.Ngod_t1t_sum#c.scot c.Ngod_t1t_sum#c.scot#c.inter  ) ///
	 indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )


************************************
*Table 7
*************************************Analysis*************************************************
use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear

********************

global controls unemploymentrate gdp100
global post1970int oilexistsXscotXhy_1970_1-oilexistsXscotXhy_2000_2 

forvalues i=1(1)7 {
local j=10*`i'
gen Ddecade_`i'=0
replace Ddecade_`i'=1 if year>=1930+`j' & year<(1940+`j')
gen Ddecadescot`i'=Ddecade_`i'*scot
}


eststo estTX1: ivreg2 nationalistvoteshare100 hy_* scot c.scot#i.oilexists i.constituency_id,cluster (constituencyname hyear)  
eststo estTX2: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot  Ddecadescot1-Ddecadescot3 Ddecadescot5-Ddecadescot7 i.constituency_id,cluster (constituencyname hyear)  
eststo estTX3: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot   ttrend* c.ttrend*#i.oilexists  i.constituency_id,cluster (constituencyname hyear)   
eststo estTX4: ivreg2 nationalistvoteshare100 hy_* i.constituency_id c.Ngod_t1t_sum##scot  thatcher_x_scot ttrend*  ,cluster (constituencyname hyear)   
eststo estTX5: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot c.f4.Ngod_t1t_sum##scot   i.constituency_id  ,cluster (constituencyname hyear)  
eststo estTX6: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot i.year#c.rel_mining  i.constituency_id   ,cluster (constituencyname hyear)  


estout estTX* using "tables\Table7.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par( ) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
		keep( 1.scot#c.Ngod_t1t_sum 1.scot#cF4.Ngod_t1t_sum 1.oilexists#c.scot  ) varlabel(1.scot#cF4.Ngod_t1t_sum "Lead (t+1)") ///
	order(1.scot#c.Ngod_t1t_sum  1.scot#cF4.Ngod_t1t_sum  ) ///
	indicate( hy* 2.constituency_id ttrend2 1946.year#c.rel_mining , labels(yes no) )

	
******************************************************************************************************************
*TABLE 8 , triple differences
*****************************************************************************************************************
estimates drop _all

quietly{
local i=1
eststo est6`i': ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Nod_t1t_sum#i.scot c.Nod_t1t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
local i=`i'+1
eststo est6`i':  ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t1t_sum#i.scot c.Ngod_t1t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
local i=`i'+1
*Amount of discoveries
eststo est6`i':  ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t1t_sum#i.scot c.mRd_t1t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
local i=`i'+1
eststo est6`i':  ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mGd_t1t_sum#i.scot c.mGd_t1t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
}

estout est6* using "tables\Table8.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par( ) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
		keep( c.Nod_t1t_sum#c.bp2001aXs   c.Ngod_t1t_sum#c.bp2001aXs  c.mRd_t1t_sum#c.bp2001aXs  c.mGd_t1t_sum#c.bp2001aXs ) ///
	order(c.Nod_t1t_sum#c.bp2001aXs   c.Ngod_t1t_sum#c.bp2001aXs  c.mRd_t1t_sum#c.bp2001aXs  c.mGd_t1t_sum#c.bp2001aXs ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )	

******Table Appendix, containing  main effects
estout est6* using "tables\TableA19.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab ) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
		keep(bp2001aXs 1.scot#c.Nod_t1t_sum c.Nod_t1t_sum#c.bp2001aXs   1.scot#c.Ngod_t1t_sum   c.Ngod_t1t_sum#c.bp2001aXs 1.scot#c.mRd_t1t_sum c.mRd_t1t_sum#c.bp2001aXs ///
		1.scot#c.mGd_t1t_sum c.mGd_t1t_sum#c.bp2001aXs ) ///
	order(bp2001aXs 1.scot#c.Nod_t1t_sum c.Nod_t1t_sum#c.bp2001aXs   1.scot#c.Ngod_t1t_sum   c.Ngod_t1t_sum#c.bp2001aXs 1.scot#c.mRd_t1t_sum c.mRd_t1t_sum#c.bp2001aXs ///
		1.scot#c.mGd_t1t_sum c.mGd_t1t_sum#c.bp2001aXs ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )	
	
	
	
	
********************************************************************************************************************	
*TABLE 9: Placebo Test
********************************************************************************************************************
quietly{
eststo est7A:  ivreg2 nationalistvoteshare100 i.constituency_id  hy_*  brentprice2001_avg_x_scot $controls  if year<=1969, cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a) 	
eststo est7B:  ivreg2 nationalistvoteshare100 i.constituency_id  hy_* brentprice2001_avg_x_scot $controls   if year>=1970, cluster (constituencyname hyear) 
estadd scalar adj_R =e(r2_a)		
eststo est7C: ivreg2 nationalistvoteshare100 i.constituency_id  hy_*  c.brentprice2001avg_diff5#c.scot $controls  if year<=1969, cluster (constituencyname hyear)	
estadd scalar adj_R =e(r2_a)	
eststo est7D: ivreg2 nationalistvoteshare100 i.constituency_id  hy_*  c.brentprice2001avg_diff5#c.scot $controls   if year>=1970, cluster (constituencyname hyear) 
estadd scalar adj_R =e(r2_a)	
}

estout est7* using "tables\Table9.txt", ///
replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par( ) vacant("") label(p-value))) style(tab) delimiter(_tab )  ///
stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3)) keep(brentprice2001_avg_x_scot  c.brentprice2001avg_diff5#c.scot  ) ///
order( brentprice2001_avg_x_scot c.brentprice2001avg_diff5#c.scot  ) indicate( hy* , labels(yes no) )



	
***Appendix	

*Descriptive Stats full table  
 use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear


**********TABLE A11**********
gen landlocked = 0
replace landlocked= 1 if seaside==0
*Summary Statistics
format %9.3f nationalistvoteshare100 Ngod_t1t_sum Nod_t0t_sum  scot brentprice2001_avg brentprice2001avg_diff5 SDbrentprice2001_mon annualproductionb unemploymentrate gdp100 mGd_t1t_sum mRd_t1t_sum nearborder50 nearborder75 nearborder100     ///
landlocked dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga   rel_englRES  rel_industry  rel_agriculture   rel_government  rel_whitecollar   rel_educationRES rel_edutermU15ALLED1951  

sum nationalistvoteshare100 Ngod_t1t_sum Nod_t0t_sum  scot brentprice2001_avg brentprice2001avg_diff5 SDbrentprice2001_mon annualproductionb unemploymentrate gdp100 mGd_t1t_sum mRd_t1t_sum nearborder50 nearborder75 nearborder100     ///
landlocked dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga   rel_englRES  rel_industry  rel_agriculture   rel_government  rel_whitecollar   rel_educationRES rel_edutermU15ALLED1951  ,format

matrix input A=(0, 0, 0, 0 ,0 \ 0, 0, 0, 0 ,0 \ 0, 0 ,0,0,0  \0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0 \0, 0 ,0,0,0  \0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0 \0, 0 ,0,0,0  \0, 0, 0,0,0 \0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0\0, 0, 0,0,0)

local no=1
foreach var in nationalistvoteshare100 Ngod_t1t_sum Nod_t0t_sum  scot brentprice2001_avg brentprice2001avg_diff5 SDbrentprice2001_mon annualproductionb unemploymentrate gdp100 mGd_t1t_sum mRd_t1t_sum nearborder50 nearborder75 nearborder100     ///
landlocked dist_d_Aberdeen av_soilsuitability ra_ruggedness_index_nunn_puga   rel_englRES  rel_industry  rel_agriculture   rel_government  rel_whitecollar   rel_educationRES  rel_edutermU15ALLED1951     {
sum `var' if nationalistvoteshare != .
local obs=r(N)

local mean=r(mean)
local sd=r(sd)
local min=r(min)
local max=r(max)

matrix A[`no',1]=`obs'
matrix A[`no',2]=`mean'
matrix A[`no',3]=`sd'
matrix A[`no',4]=`min'
matrix A[`no',5]=`max'

local no=`no'+1
}
	

matrix rownames A = "Secessionist vote share" "Discoveries (giant)" "Discoveries (all)"  "Scotland" "Oil price" "Oil price deviation" "Oil price SD (within-year)" "Oil production" "Unemployment rate" "GDP per capita" ///
 "Amount of new reserves (giant)" "Amount of new reserves" "Near border (50)" "Near border (75)" "Near border (100)" "Landlocked constituency" "Distance to Aberdeen" "Avg soil suitability" "Ruggedness index" "Share of English residents" ///
 "Share in industry sector" "Share in agric sector" "Share in govt sector" "Share of white collar workers" "Share in education sector" "Share with low education"  
matrix colnames A=Obs Mean SD Min Max
mat list A

estout matrix(A, fmt(0 2 2 2 2 ) )using "tables\TableA11.txt",replace   ///
style(tab) delimiter(_tab ) title(Descriptives)   


********Appendix TABLE A12, alternative clustering
estimates drop _all
quietly{
eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
}
estout est2* using "tables\TableA12.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value))  ) /// 
	style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )

	
	
*TABLE A13, alternative clustering
estimates drop _all
quietly{
eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",cluster (hyear )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,cluster (hyear )
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,cluster (hyear )
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (hyear )
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (hyear )
estadd scalar adj_R =e(r2_a)
}
estout est2* using "tables\TableA13.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value))  ) /// 
	style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )


*TABLE A14, alternative clustering
estimates drop _all
quietly{
eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
}
estout est2* using "tables\TableA14.txt", ///
	replace title("clustering country times time") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value))  ) /// 
	style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )



*TABLE A15,  alternative clustering 
estimates drop _all
quietly{
eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",cluster (country_time_cat )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (country_time_cat )
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (country_time_cat )
estadd scalar adj_R =e(r2_a)
}
estout est2* using "tables\TableA15.txt", ///
	replace title("clustering country times time category") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value))  ) /// 
	style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )
	
	
		

*TABLE A16, alternative clustering xtpcse
xtset constituency_id hyear
estimates drop _all
quietly{
eststo est2A:xtpcse nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland",correlation(ar1)   
estadd scalar adj_R =e(r2_a)
eststo est2B: xtpcse nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot ,correlation(ar1)
estadd scalar adj_R =e(r2_a)
eststo est2C: xtpcse nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  ,correlation(ar1)
estadd scalar adj_R =e(r2_a)
eststo est2E:  xtpcse  nationalistvoteshare100 hy_*   i.constituency_id   c.Ngod_t1t_sum##scot tt_scot $controls , correlation(ar1)
estadd scalar adj_R =e(r2_a)
eststo est2F: xtpcse nationalistvoteshare100  hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls  ,correlation(ar1)
estadd scalar adj_R =e(r2_a)
}

estout est2* using "tables\TableA16.txt", ///
	replace title("xtpcse with panel specific auto-correlation") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value))  ) /// 
	style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )

*Bootstrap in here
/*
 use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear
********************************Bootstrap	*****************************************************************************************************
cap noisily gen treat=Ngod_t1t_sum*scot 
cap noisily drop  uR xbR		
ivreg2 nationalistvoteshare100 treat  hy_*  id*  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (country_time_cat )		
	*Restricted wild bootstrap
 boot nationalistvoteshare100    treat  hy_*  id* tt_scot  $controls    ,unit(country_time_cat  )  bots(2000)  
  local append replace
 global Pvalue_Rademacher =r(Pvalue_Rad)
  global Pvalue_Webb=r(Pvalue_Webb)
 display "Pvalue_Rademacher=" $Pvalue_Rademacher "  &  Pvalue_Webb="$Pvalue_Webb	
	
*Appendix table, alternative clustering,  bootstrap constituency level
estimates drop _all
*quietly{
************************************Restricted wild bootstrap**********************************************************************************
***********************************************************************************************************************************************
boot nationalistvoteshare100    treat  hy_*  id* tt_scot  $controls    ,unit(country_time  )  bots(10000)  
local Pvalue_Rademacher =r(Pvalue_Rad)
local Pvalue_Webb=r(Pvalue_Webb)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
estadd scalar Pvalue_Rademacher =`Pvalue_Rademacher'
**************************
boot nationalistvoteshare100    treat  hy_*  id* tt_scot  $controls ttrend*   ,unit(country_time  )  bots(10000)  
local Pvalue_Rademacher =r(Pvalue_Rad)
local Pvalue_Webb=r(Pvalue_Webb)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (country_time )
estadd scalar adj_R =e(r2_a)
estadd scalar Pvalue_Rademacher =`Pvalue_Rademacher'
*}
estout est2* using "tables\TableA17.txt", ///
	replace title("country times time") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par([ ]) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N Pvalue_Rademacher , labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   $controls )  ///
	order( 1.scot#c.Ngod_t1t_sum   $controls ) indicate( hy* 2.constituency_id tt_scot   , labels(yes no) )

			
*TABLE A17, Table 2 alternative clustering bootstrap country times time category level
estimates drop _all
*quietly{
boot nationalistvoteshare100    treat  hy_*  id* tt_scot  $controls    ,unit(country_time_cat  )  bots(10000)  
local Pvalue_Rademacher =r(Pvalue_Rad)
local Pvalue_Webb=r(Pvalue_Webb)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls ,cluster (country_time_cat )
estadd scalar adj_R =e(r2_a)
estadd scalar Pvalue_Rademacher =`Pvalue_Rademacher'
**************************
boot nationalistvoteshare100    treat  hy_*  id*  $controls ttrend*   ,unit(country_time_cat  )  bots(10000)  
local Pvalue_Rademacher =r(Pvalue_Rad)
local Pvalue_Webb=r(Pvalue_Webb)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls ,cluster (country_time_cat )
estadd scalar adj_R =e(r2_a)
estadd scalar Pvalue_Rademacher =`Pvalue_Rademacher'
*}
estout est2* using "tables\TableA17.txt", ///
	append title("Country times timecategory bootstrap") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par([ ]) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N Pvalue_Rademacher Pvalue_Webb, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   $controls ) ///
	order( 1.scot#c.Ngod_t1t_sum   $controls ) indicate( hy* 2.constituency_id tt_scot   , labels(yes no) )
*/

	
******************
 use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear
*TABLE A18 
estimates drop _all
quietly{
eststo est2A:reg nationalistvoteshare100   Ngod_t1t_sum  i.constituency_id   $controls if country_name == "Scotland"&byelection==0,cluster (constituencyname )
estadd scalar adj_R =e(r2_a)
eststo est2B: ivreg2 nationalistvoteshare100  hy_*  c.Ngod_t1t_sum##scot if byelection==0,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2C: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot tt_scot  if byelection==0,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2E: ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls if byelection==0,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est2F: ivreg2 nationalistvoteshare100 hy_* ttrend* i.constituency_id  c.Ngod_t1t_sum##scot  $controls if byelection==0,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
}
estout est2* using "tables\TableA18.txt", ///
	replace title("no byelections") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par([ ]) vacant("") label(p-value))) style(tab) delimiter(_tab )  ///
	stats( r2_a N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum  ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot Ngod_t1t_sum   ) indicate( hy* 2.constituency_id tt_scot ttrend*  , labels(yes no) )		

	
*Appendix Table A20
estimates drop _all
quietly{
eststo est6A: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t1t_py#i.scot c.mRd_t1t_py##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est6B: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t2t_py#i.scot c.mRd_t2t_py##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est6C: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t3t_py#i.scot c.mRd_t3t_py##c.bp2001aXs $controls ,cluster (constituencyname hyear)	
estadd scalar adj_R =e(r2_a)
eststo est6D: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t4t_py#i.scot c.mRd_t4t_py##c.bp2001aXs $controls ,cluster (constituencyname hyear)	
estadd scalar adj_R =e(r2_a)
eststo est6F: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t1t_sum#i.scot c.mRd_t1t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est6G: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t2t_sum#i.scot c.mRd_t2t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est6H: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t3t_sum#i.scot c.mRd_t3t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)	
estadd scalar adj_R =e(r2_a)
eststo est6I: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t4t_sum#i.scot c.mRd_t4t_sum##c.bp2001aXs $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)		

}
estout est6* using "tables\TableA20.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par({ }) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(c.mRd_t1t_py#c.bp2001aXs c.mRd_t2t_py#c.bp2001aXs c.mRd_t3t_py#c.bp2001aXs c.mRd_t4t_py#c.bp2001aXs   ///
	c.mRd_t1t_sum#c.bp2001aXs  c.mRd_t2t_sum#c.bp2001aXs  c.mRd_t3t_sum#c.bp2001aXs   c.mRd_t4t_sum#c.bp2001aXs    ) ///
	order(c.mRd_t1t_py#c.bp2001aXs c.mRd_t2t_py#c.bp2001aXs c.mRd_t3t_py#c.bp2001aXs c.mRd_t4t_py#c.bp2001aXs   ///
	c.mRd_t1t_sum#c.bp2001aXs  c.mRd_t2t_sum#c.bp2001aXs  c.mRd_t3t_sum#c.bp2001aXs   c.mRd_t4t_sum#c.bp2001aXs   ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )

*TABLE A21 
quietly{
eststo est5A: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t1t_sum##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5B: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t2t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5C: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t3t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5D: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t4t_sum##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5F: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id  c.mRd_t1t_py##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5G: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t2t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5H: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.mRd_t3t_py##scot $controls  ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
eststo est5I: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id  c.mRd_t4t_py##scot $controls ,cluster (constituencyname hyear)
estadd scalar adj_R =e(r2_a)
}

estout est5* using "tables\TableA21.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )starlevels(* 0.10 ** 0.05 *** 0.01) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.mRd_t1t_sum   1.scot#c.mRd_t1t_sum  1.scot#c.mRd_t2t_sum   1.scot#c.mRd_t3t_sum   ///
	1.scot#c.mRd_t4t_sum    1.scot#c.mRd_t1t_py  1.scot#c.mRd_t2t_py    1.scot#c.mRd_t3t_py ///
	1.scot#c.mRd_t4t_py    ) ///
	order( 1.scot#c.mRd_t1t_sum  1.scot#c.mRd_t2t_sum    1.scot#c.mRd_t3t_sum ///
	1.scot#c.mRd_t4t_sum    1.scot#c.mRd_t1t_py  1.scot#c.mRd_t2t_py    1.scot#c.mRd_t3t_py ///
	1.scot#c.mRd_t4t_py    ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
	
*Appendix Table A22 
use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear

********************
global controls unemploymentrate gdp100
global post1970int oilexistsXscotXhy_1970_1-oilexistsXscotXhy_2000_2 

forvalues i=1(1)7 {
local j=10*`i'
gen Ddecade_`i'=0
replace Ddecade_`i'=1 if year>=1930+`j' & year<(1940+`j')
gen Ddecadescot`i'=Ddecade_`i'*scot
}

 ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot  scot#Ddecade_1-Ddecade_3 scot#Ddecade_5-Ddecade_7 i.constituency_id ,cluster (constituencyname hyear)  
eststo estA71: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot  /// 
Ddecadescot1-Ddecadescot3 Ddecadescot5-Ddecadescot7 i.constituency_id ///
,cluster (constituencyname hyear)   

eststo estA72: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot  ///
Ddecadescot1-Ddecadescot3 Ddecadescot5-Ddecadescot7 i.constituency_id tt_scot /// 
,cluster (constituencyname hyear)   
eststo estA74:  ivreg2 nationalistvoteshare100 hy_* i.constituency_id c.Ngod_t1t_sum##scot  tt_scot $controls if year<1997,cluster (constituencyname hyear)  

estout estA7* using "tables\TableA22.txt", ///
	replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par( ) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
	stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
		keep( 1.scot#c.Ngod_t1t_sum    Ddecadescot1 Ddecadescot2 Ddecadescot3 Ddecadescot5 Ddecadescot6 Ddecadescot7) ///
	order(1.scot#c.Ngod_t1t_sum  Ddecadescot1 Ddecadescot2 Ddecadescot3 Ddecadescot5 Ddecadescot6 Ddecadescot7 ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )

	
****Table A23
	forvalues j=6(1)9 {
*1
eststo estTXA`j': ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls Ddecadescot* if year!=19`j'0 &year!=19`j'1 &year!=19`j'2 &year!=19`j'3 &year!=19`j'4 &year!=19`j'5 &year!=19`j'6 &year!=19`j'7 &year!=19`j'8 &year!=19`j'9  ,cluster (constituencyname hyear)
} 
*2
eststo estTXA9a:ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls Ddecadescot*  if year!=1970& year!=1971& year!=1972& year!=1973& year!=1974  ,cluster (constituencyname hyear) 
eststo estTXA9b:ivreg2 nationalistvoteshare100 hy_*  i.constituency_id  c.Ngod_t1t_sum##scot tt_scot $controls Ddecadescot*  if year>1979  ,cluster (constituencyname hyear) 
estout estTXA* using "tables\TableA23.txt", ///
	replace title("Excluding Decades") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( N, labels(  "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum          ) ///
	order( 1.scot#c.Ngod_t1t_sum     ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )


****Table A24 
quietly{
eststo estA81: ivreg2 nationalistvoteshare100 hy_* oilexists_x_scot scot    ,cluster (constituencyname hyear)   
eststo estA82: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t1t_sum##scot c.f4.Ngod_t1t_sum##scot    ,cluster (constituencyname hyear)  
eststo estA83: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t2t_sum##scot c.f6.Ngod_t2t_sum##scot    ,cluster (constituencyname hyear)  
eststo estA84: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t3t_sum##scot c.f8.Ngod_t3t_sum##scot   ,cluster (constituencyname hyear)   
eststo estA85: ivreg2 nationalistvoteshare100 hy_* c.Ngod_t4t_sum##scot c.f10.Ngod_t4t_sum##scot   ,cluster (constituencyname hyear)   
}

estout estA8* using "tables\TableA24.txt", ///
replace title("-") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
se(fmt(3) par([ ]) vacant("") label(SE))p(fmt(3) par( ) vacant("") label(p-value))) style(tab) delimiter(_tab ) ///
stats( adj_R N, labels( "Adj. R-Squared" "Number of Observations") fmt( 2 0 3 3))  ///
keep( oilexists_x_scot    1.scot#c.Ngod_t1t_sum 1.scot#cF4.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum 1.scot#cF6.Ngod_t2t_sum  1.scot#c.Ngod_t3t_sum 1.scot#cF8.Ngod_t3t_sum  1.scot#c.Ngod_t4t_sum 1.scot#cF10.Ngod_t4t_sum  )  ///
order() ///
indicate( hy*  , labels(yes no) )	
	


			
*********************************************************	
************************APPENDIX*************************
*********************************************************

use "data_final_extended.dta", clear
set more off,perm
***************************
xtset constituency_id hyear

********************
global controls unemploymentrate gdp100
global post1970int oilexistsXscotXhy_1970_1-oilexistsXscotXhy_2000_2 

global timeinvariantcontrols border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff ra_wheat_int_rf_resample ra_wheat_int_irr_resample ra_potato_int_rf_resample ra_potato_int_irr_resample ///
ra_barley_int_rf_resample ra_barley_int_irr_resample
global timeinvariantcontrols_short border_En_Sc border_En_Wa seaside_scot seaside_wales dist_b_EN_SC dist_b_EN_WA dist_d_Edinburgh ///
dist_d_Cardiff 

forvalues i=1(1)7 {
local j=10*`i'
gen Ddecade_`i'=0
replace Ddecade_`i'=1 if year>=1930+`j' & year<(1940+`j')
gen Ddecadescot`i'=Ddecade_`i'*scot
}
 
estimates drop _all

*weighting shown in appendix
replace electorate2001=round(electorate2001,1)
eststo est3wA: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t1t_sum##scot   $controls [fweight=electorate2001] ,cluster (constituencyname hyear) 
eststo est3wB: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t2t_sum##scot   $controls [fweight=electorate2001] ,cluster (constituencyname hyear) 
eststo est3wC: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t3t_sum##scot   $controls [fweight=electorate2001] ,cluster (constituencyname hyear) 
eststo est3wD: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t4t_sum##scot   $controls [fweight=electorate2001] ,cluster (constituencyname hyear) 
               
estout est3w* using "tables\TableA25.txt", ///
	replace title("Weighted Least Squares") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( , labels(   ) fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum        ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum       ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
 
*without zero observations
eststo est3zA: ivreg2 nationalistvoteshare100 hy_*  tt_scot i.constituency_id c.Ngod_t1t_sum##scot $controls if nationalistvoteshare!=0 ,cluster (constituencyname hyear)
eststo est3zB: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t2t_sum##scot $controls if nationalistvoteshare!=0  ,cluster (constituencyname hyear)
eststo est3zC: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t3t_sum##scot $controls if nationalistvoteshare!=0 ,cluster (constituencyname hyear)
eststo est3zD: ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t4t_sum##scot $controls if nationalistvoteshare!=0 ,cluster (constituencyname hyear)

estout est3z* using "tables\TableA25.txt", ///
	append title("Excluding Zero Observations") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( N, labels(  "Number of Observations") fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum      ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum      ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
 
*initial share
cap drop  av_nationlistvoteshare100_60s
cap drop  t_av_nationlistvoteshare100_60s
bys Ddecade_3 constituency_id: egen t_av_nationlistvoteshare100_60s= mean(nationalistvoteshare100)
replace   t_av_nationlistvoteshare100_60s=. if Ddecade_3==0
bys constituency_id: egen av_nationlistvoteshare100_60s=mean(t_av_nationlistvoteshare100_60s)

cap drop  av_nationlistvoteshare100_50s
cap drop  t_av_nationlistvoteshare100_50s
bys Ddecade_2 constituency_id: egen t_av_nationlistvoteshare100_50s= mean(nationalistvoteshare100)
replace   t_av_nationlistvoteshare100_50s=. if Ddecade_2==0
bys constituency_id: egen av_nationlistvoteshare100_50s=mean(t_av_nationlistvoteshare100_50s)

gen av_nationlistvoteshare100_50a60s= (av_nationlistvoteshare100_50s+av_nationlistvoteshare100_60s)/2
  
  forvalues j=1(1)4{
eststo est3v1`j': ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t`j't_sum##scot##c.av_nationlistvoteshare100_60s  $controls ,cluster (constituencyname hyear)
  }
 estout est3v1`j'* using "tables\TableA25.txt", ///
	append title("Initial Vote Share 60") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( , labels(   ) fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum        ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum       ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
	
 forvalues j=1(1)4{
 eststo est3v2`j': ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t`j't_sum##scot##c.av_nationlistvoteshare100_50s  $controls ,cluster (constituencyname hyear) 
  }
estout est3v2`j'* using "tables\TableA25.txt", ///
	append title("Initial Vote Share 50") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( , labels(   ) fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum        ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum       ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
  
  forvalues j=1(1)4{
eststo est3v3`j': ivreg2 nationalistvoteshare100 hy_* tt_scot i.constituency_id c.Ngod_t`j't_sum##scot##c.av_nationlistvoteshare100_50a60s $controls ,cluster (constituencyname hyear)
  }
estout est3v3`j'* using "tables\TableA25.txt", ///
	append title("Initial Vote Share 50-60") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
	stats( , labels(   ) fmt( 2 0 3 3))  ///
	keep(1.scot#c.Ngod_t1t_sum   1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum   1.scot#c.Ngod_t3t_sum   ///
	1.scot#c.Ngod_t4t_sum        ) ///
	order( 1.scot#c.Ngod_t1t_sum  1.scot#c.Ngod_t2t_sum    1.scot#c.Ngod_t3t_sum ///
	1.scot#c.Ngod_t4t_sum       ) ///
	indicate( hy* 2.constituency_id tt_scot  , labels(yes no) )
	
eststo estTAS1:ivreg2 nationalistvoteshare100 hy_*  i.constituency_id c.Ngod_t1t_sum##c.brentprice2001avg_diff5##c.scot  $controls ,cluster (constituencyname hyear)  
eststo estTAS3:ivreg2 nationalistvoteshare100 hy_*  i.constituency_id c.Ngod_t1t_sum##c.brentprice2001_avg##c.scot  c.Ngod_t1t_sum##c.SDbrentprice2001_mon#c.scot $controls if year>1969 ,cluster (constituencyname hyear)	
eststo estTAS2:ivreg2 nationalistvoteshare100 hy_*  i.constituency_id c.Ngod_t1t_sum##c.SDbrentprice2001_mon#c.scot $controls if year>1969 ,cluster (constituencyname hyear)	

estout estTAS* using "tables\TableA26.txt", ///
	replace title("Deviation") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
	se(fmt(3) par([ ]) vacant("") label(SE))) style(tab) delimiter(_tab )  ///
	stats(  N, labels(  "Number of Observations") fmt(  0 3 3))  ///
	keep(c.brentprice2001avg_diff5#c.scot  c.Ngod_t1t_sum#c.brentprice2001avg_diff5#c.scot c.Ngod_t1t_sum#c.brentprice2001_avg#c.scot c.brentprice2001_avg#c.scot c.SDbrentprice2001_mon#c.scot c.SDbrentprice2001_mon#c.scot c.Ngod_t1t_sum#c.SDbrentprice2001_mon#c.scot  ) 


	
	
***************Appendix: Multi-Country Study

use "combined_data_cleaned3.dta", clear

*Descriptive Statistics 
matrix input A=(0, 0, 0, 0 ,0 \0, 0, 0, 0 ,0 \ 0,0,0,0,0  \ 0,0,0,0,0  \0, 0 ,0,0,0 )

local no=1
foreach var of varlist votes gdp_ratio enep lang pop {
sum `var' if gdp_ratio!=. & votes!=.
local obs=r(N)
local mean=r(mean)
local sd=r(sd)
local min=r(min)
local max=r(max)

matrix A[`no',1]=`obs'
matrix A[`no',2]=`mean'
matrix A[`no',3]=`sd'
matrix A[`no',4]=`min'
matrix A[`no',5]=`max'


local no=`no'+1
}


matrix rownames A =\textit{Secessionist~vote~share} \textit{Relative~wealth} \textit{Electoral~parties} \textit{Regional~language} \textit{Regional~population} 
matrix colnames A=N Mean SD Min Max 
mat list A


estout matrix(A, fmt(0 2 2 2 2 ) )using "tables\TableA3.txt",replace   ///
style(tab) delimiter(_tab ) title() 
  

use "data_final_extended.dta", clear
xtset constituency_id hyear
sort hyear

*Figure15
 line geturnout_wales  hyear , lcolor(gs0    ) lpattern(dot) lwidth(medthick) ///
|| line  geturnout_scot hyear , lcolor(gs0    )  lpattern(dot) lwidth(medthick) ///
 || scatter geturnout_wales geturnout_scot  hyear ///
, msymbol(dot  dot dot) msize(med med med )  mcolor( "255 147 127" "14 61 136") yline(0 20 40 60 80 100 , lwidth( thin ) lcolor(gs13))  ///  
ylabel(0(20)100)  ytick(0(10)100) xlabel(-30(10)82) xtick(-30(10)82) xlabel(-20 "1950" 0  "1960" 20 "1970" 40 "1980" 60 "1990" 80 "2000" )  /// 
 graphregion(color(white))   ytitle(%) legend(order(4 3)) xtitle(Year)
  graph export "graphics/FigureA15.png", width(3000) replace
  window manage  close graph _all	 


*Figure16
bysort hyear: egen SNPavg = mean(nationalistvoteshare100) if country_name == "Scotland" & byelection == 0
bysort hyear: egen PCavg = mean(nationalistvoteshare100) if country_name == "Wales" & byelection == 0

gen SNPshare = nationalistvoteshare100 if country_name=="Scotland" 
gen PCshare = nationalistvoteshare100 if country_name=="Wales"

bysort hyear: egen PCavg2 = mean(PCavg) if byelection == 0
bysort hyear: egen SNPavg2 = mean(SNPavg) if byelection == 0

label var SNPavg2 "SNP Vote Share"
label var PCavg2 "Plaid Cymru Vote Share"
 
 line geturnout_wales  hyear , lcolor(  "255 207 195"  ) lpattern(dash) lwidth(medthick) ///
|| line  geturnout_scot hyear , lcolor("89 122 173"    )  lpattern(dash) lwidth(medthick) ///
 || scatter  PCavg2 SNPavg2 hyear ///
, msymbol(dot  dot dot) msize(med med med )  mcolor(  "255 147 127" "14 61 136" ) yline(0 20 40 60 80 100 , lwidth( thin ) lcolor(gs13))  ///  
ylabel(0(20)100)  ytick(0(10)100) xlabel(-30(10)82) xtick(-30(10)82) xlabel(-20 "1950" 0  "1960" 20 "1970" 40 "1980" 60 "1990" 80 "2000" )  ///
 graphregion(color(white))   ytitle(%) legend(order(4 3 2 1)) xtitle(Year)
  graph export "graphics/FigureA16.png", width(3000) replace
  

*Figure17
 line gvote_con_scot  hyear , lcolor(gs0    ) lpattern(dot) lwidth(medthick) ///
|| line gvote_lab_scot hyear , lcolor(gs0   ) lpattern(dot) lwidth(medthick) ///
|| line gvote_snp_scot  hyear, lcolor(gs0   ) lpattern(dot) lwidth(medthick) ///  
 || scatter gvote_con_scot gvote_lab_scot  gvote_snp_scot hyear  ///
, msymbol(dot  dot dot) msize(small small med )  mcolor(gs12  gs7   "14 61 136") yline(0 10 20 30 40 50 , lwidth( thin ) lcolor(gs13))  ///  
ylabel(0(10)50)  ytick(0(10)50) xlabel(-30(10)82) xtick(-30(10)82) xlabel(-20 "1950" 0  "1960" 20 "1970" 40 "1980" 60 "1990" 80 "2000"  )  ///  
 graphregion(color(white))   ytitle(%) legend(order(4 5 6)) xtitle(Year)
  graph export "graphics/FigureA17.png", width(3000) replace


*Figure18
twoway  (scatter  SNPavg2 hyear if countryname=="Scotland" & year>1969, yaxis(1) ylabel(0(10)40, axis(1))   msymbol( dot dot ) msize(medlarge medsmall) mcolor("14 61 136" ))  ///
(line annualvaluescot_gdpshare hyear if countryname=="Scotland" & year>1969, yaxis(2) ylabel(0(0.2)1, axis(2))  lpattern(shortdash) lcolor(gs11) ) , ///
ytitle("%", margin( small ))  ///
   xtitle("Year", margin( small ))  xlabel( 20 "1970" 40 "1980" 60 "1990" 80 "2000" ) ytick(0 10 20 30 40) xtick( 20 30 40 50 60 70 80) yline(0 10 20 30 40  , lwidth( thin ) lcolor(gs13)) ///
   legend(   label( 1  "SNP average vote share") label(2 "Annual oil revenues as a %" "of Scottish (onshore) GDP" )  region(col(white)) ) ///
   graphregion(color(white)) 
 graph export     "graphics\FigureA18.png",width(4000) replace 
window manage  close graph _all	 

 	
 
 
 
*****Graphic Cross-Country Appendix

use "combined_data_cleaned3.dta", clear

replace votes=votes*10 if region_name=="Bavaria"
//This is done for simplicity. Manually change the scaling in the graph
//Manually move some of the graphs within one panel so that they appear in the correct position

levelsof numerator, local(numer)
levelsof provelec, local(prov)
foreach j of local prov{
	foreach i of local numer {
		twoway (scatter votes elec_year if votes!=. &gdp_ratio2!=. , yaxis(1) color("255 147 127")) ///
		(scatter gdp_ratio2 elec_year if votes!=. &gdp_ratio2!=. , yaxis(2) color("14 61 136") msize(medsmall) ) ///
		(lowess votes elec_year if votes!=. &gdp_ratio2!=., yaxis(1) color("255 147 127") mean bwidth(0.7) lwidth(medthin)) ///
		(lowess gdp_ratio2 elec_year if votes!=. &gdp_ratio2!=., yaxis(2)  color("14 61 136" )  mean bwidth(0.3) lwidth(thin) lpattern(shortdash)) ///
		if numerator == `i' & provelec == `j' & N_elec > 2 &  elec_year >= 1970 &region_name!="Scotland"&region_name!="Wales", by(reg_sh_country,  title("Secessionist Vote Share and Relative Wealth") l1title("Secessionist Vote Share") r1title("Relative Wealth") note("") ///
		graphregion(color(white)) imargin(medium) cols(2) iscale(.6) iy ix) ysize(20) xsize(20) xlabel(1970 1985 2000 2015) ylabel(0 20 40 60 80, axis(1)) ylabel(50 75 100 125 150, axis(2)) ///
		legend( order(1 "Secessionist Vote Share" 3 "Relative Income") )
		
		graph export "graphics/FigureA`i'(`j').png", width(3000) replace
		window manage  close graph _all	 
	}
}

*Extra Graphic with Veneto and other countries as dummy; will be dropped from graphic but used so that Veneto appears in the right place
twoway (scatter votes elec_year if votes!=. &gdp_ratio2!=. , yaxis(1) color("255 147 127")) ///
		(scatter gdp_ratio2 elec_year if votes!=. &gdp_ratio2!=. , yaxis(2) color("14 61 136") msize(medsmall) ) ///
		(lowess votes elec_year if votes!=. &gdp_ratio2!=., yaxis(1) color("255 147 127") mean bwidth(0.7) lwidth(medthin)) ///
		(lowess gdp_ratio2 elec_year if votes!=. &gdp_ratio2!=., yaxis(2)  color("14 61 136" )  mean bwidth(0.3) lwidth(thin) lpattern(shortdash)) ///
		if numerator == 5 & provelec == 0 & N_elec > 2 &  elec_year >= 1970 &region_name!="Scotland"&region_name!="Wales" | numerator == 7 & provelec == 0 & N_elec > 2 &  elec_year >= 1970 &region_name!="Scotland"&region_name!="Wales", by(reg_sh_country,  title("Secessionist Vote Share and Relative Wealth") l1title("Secessionist Vote Share") r1title("Relative Wealth") note("") ///
		graphregion(color(white)) imargin(medium) cols(2) iscale(.6) iy ix) ysize(20) xsize(20) xlabel(1970 1985 2000 2015) ylabel(0 20 40 60 80, axis(1)) ylabel(50 75 100 125 150, axis(2)) ///
		legend( order(1 "Secessionist Vote Share" 3 "Relative Income") )
		
		graph export "graphics/FigureA7(0)extra.png", width(3000) replace
		window manage  close graph _all	 
		
		*Shown in 2 columns, 4 in every panel
		*then on every din-a4 page, show 2 graphics 

		
 
*******************************************************************************
*********************************Cross-country*********************************
*******************************************************************************

use "combined_data_cleaned3.dta", clear

********************Regressions*******************************************************************************************************************
********************Regressions for Paper******************

estimates drop _all

eststo est2A: ivreg2 votes gdp_ratio2 i.panel, cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="No"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2B: ivreg2 votes gdp_ratio2 i.elec_year  i.panel, cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2D: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang i.elec_year  i.panel, cluster(regio  elec_year) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE="Yes"
eststo est2E: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel, cluster(regio  elec_year) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
eststo est2F: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if region_name!="Scotland"&region_name!="Wales" , cluster(regio  elec_year)
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"

 estout est2* using "tables\Table1.txt", ///
 replace title("Cross Country Table") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
 se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
 indicate("Controls=pop") ///
 stats(r2_a  N    TFE TTFE, labels( "Adj. R-Squared" "Number of Observations"   "Time FE" "Time Trend x Region FE" ) fmt( 2 0 3 3))  ///
 keep(gdp_ratio2 ) ///
 order(gdp_ratio2)

 
*Alternative clustering
estimates drop _all

eststo est2A: ivreg2 votes gdp_ratio2 i.panel, cluster(panel)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="No"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2B: ivreg2 votes gdp_ratio2 i.elec_year  i.panel, cluster(panel)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2D: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang i.elec_year  i.panel, cluster(panel) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE="Yes"
eststo est2E: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel, cluster(panel) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
eststo est2F: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if region_name!="Scotland"&region_name!="Wales" , cluster(panel)
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"


estout est2* using "tables\TableA4.txt", ///
 replace title("Cross Country Table") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
 se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
 indicate("Controls=pop") ///
 stats(r2_a  N    TFE TTFE, labels( "Adj. R-Squared" "Number of Observations"   "Time FE" "Time Trend x Region FE" ) fmt( 2 0 3 3))  ///
 keep(gdp_ratio2 ) ///
 order(gdp_ratio2)
 
 
*Alternative clustering
estimates drop _all

eststo est2A: ivreg2 votes gdp_ratio2 i.panel, cluster(regio)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="No"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2B: ivreg2 votes gdp_ratio2 i.elec_year  i.panel, cluster(regio)  
estadd scalar adj_R =e(r2_a) 
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE = "Yes"
eststo est2D: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang i.elec_year  i.panel, cluster(regio) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="No"
estadd local  RFE="Yes"
eststo est2E: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel, cluster(regio) 
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
eststo est2F: ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if region_name!="Scotland"&region_name!="Wales" , cluster(regio)
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"


estout est2* using "tables\TableA5.txt", ///
 replace title("Cross Country Table") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.)) ///
 se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
 indicate("Controls=pop") ///
 stats(r2_a  N    TFE TTFE, labels( "Adj. R-Squared" "Number of Observations"   "Time FE" "Time Trend x Region FE" ) fmt( 2 0 3 3))  ///
 keep(gdp_ratio2 ) ///
 order(gdp_ratio2)
 

 estimates drop _all
*Robustness 
forvalues r=1(1)30 {
eststo estE`r': ivreg2  votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if panel!=`r', cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
}
forvalues r=1001(1)1030 {
eststo estE`r': ivreg2  votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if panel!=`r', cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
}
estout estE* using "tables\TableA6.txt", ///
 replace title("Cross Country Table") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.))  ///
 se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
 indicate("Controls=pop")  ///
 stats(r2_a  N    TFE TTFE, labels( "Adj. R-Squared" "Number of Observations"   "Time FE" "Time Trend x Region FE" ) fmt( 2 0 3 3))  ///
 keep(gdp_ratio2 ) ///
 order(gdp_ratio2) 

 
  estimates drop _all
forvalues y=1970(1)2016 {
eststo estE`y': ivreg2 votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if elec_year!=`y', cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
}
estimates drop estE1971  estE1975 estE1973
 estout estE* using "tables\TableA7.txt", ///
 replace title("Cross Country Table") noabbrev wrap label cells(b(nostar fmt(%9.3f) vacant("") label(Coef.))  ///
 se(fmt(3) par([ ]) vacant("") label(SE)) p(fmt(3) par([ ]) vacant("") label(p-value)) ) style(tab) delimiter(_tab ) ///
 indicate("Controls=pop")  ///
 stats(r2_a  N    TFE TTFE, labels( "Adj. R-Squared" "Number of Observations"   "Time FE" "Time Trend x Region FE" ) fmt( 2 0 3 3))  ///
 keep(gdp_ratio2 ) ///
 order(gdp_ratio2) 


 ************Figure: omitting years***************
 
 coefplot estE1970 || 	estE1972 || 	estE1974 || 	estE1976 || 	estE1977 || 	estE1978 || 	estE1979 || 	estE1980 || 	estE1981 || 	estE1982 || 	estE1983 || 	estE1984 || 	estE1985 || 	estE1986 || 	estE1987 || 	estE1988 || 	estE1989 || 	estE1990 || 	estE1991 || 	estE1992 || 	estE1993 || 	estE1994  	/// 
, keep(gdp_ratio2) yline(0) bycoefs vertical byopts(yrescale) levels(90) graphregion(color(white)) mcolor("14 61 136" ) yscale(range(-0.1 0.6)) ///
xtitle(Excluded Year, color(black) size(large)) xscale(titlegap(3)) ytitle(Coef. and 90% CI, color(black) size(large))  saving(graphics/leaveouty1, replace)  xlabel(, angle(90))
     
coefplot 	 	estE1995 || 	estE1996 || 	estE1997 || 	estE1998 || 	estE1999 || 	estE2000 || 	estE2001 || 	estE2002 || 	estE2003 || 	estE2004 || 	estE2005 || 	estE2006 || 	estE2007 || 	estE2008 || 	estE2009 || 	estE2010 || 	estE2011 || 	estE2012 || 	estE2013 || 	estE2014 || 	estE2015 || 	estE2016  ///
, keep(gdp_ratio2) yline(0) bycoefs vertical byopts(yrescale) levels(90) graphregion(color(white))   mcolor("14 61 136" ) yscale(range(-0.1 0.6)) ///
xtitle(Excluded Year, color(black) size(large)) xscale(titlegap(3)) ytitle(Coef. and 90% CI, color(black) size(large))  saving(graphics/leaveouty2, replace) xlabel(, angle(90))
                                                            
graph combine "graphics/leaveouty1" "graphics/leaveouty2" , title("", color(black)) scheme(s2mono) graphregion(color(white))  ycommon rows(2)


graph export "graphics/FigureA9.png", width(3500) replace


estimates drop _all
 
 **************************Figure: Leave on out - panels **************************

forvalues r=1(1)30 {

eststo _`r': ivreg2  votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if panel!=`r', cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
}
forvalues r=1001(1)1030 {

eststo _`r': ivreg2  votes gdp_ratio2 pop enep i.time#c.lang  i.elec_year i.panel c.time#i.panel if panel!=`r', cluster(regio  elec_year)  
estadd scalar adj_R =e(r2_a)
estadd local  TFE="Yes"
estadd local  TTFE="Yes"
estadd local  RFE="Yes"
}

coefplot _1|| _2	|| _3	||_4	||_5	||_6	||_7	||_8	||_9	||_10||	_11	||_12	||_13	||_14	||_15	||_16	||_17	||_18	||_19 ||_20 	||	_21||	_22||	_23||	_24||	_25||	_26||	_27||	_28||	_29||	_30 ///
, keep(gdp_ratio2) yline(0) bycoefs vertical byopts(yrescale) levels(90) graphregion(color(white))  mcolor("14 61 136" ) yscale(range(-0.1 0.6)) ///
xtitle(Excluded Region, color(black) size(large)) xscale(titlegap(3)) ytitle(Coef. and 90% CI, color(black) size(large)) title(National Elections, color(black) size(large) ) saving(graphics/leaveout1, replace)   
     
coefplot 	_1001||	_1002||	_1003||	_1004||	_1005||	_1006||	_1007||	_1008||	_1009||	_1010||	_1011||	_1012||	_1013||	_1014||	_1015||	_1016||	_1017||	_1018||	_1019	||_1020	||_1021||	_1022	||_1023||	_1024||	_1025||	_1026||	_1027	||_1028	||_1029||_1030 ///
, keep(gdp_ratio2) yline(0) bycoefs vertical byopts(yrescale) levels(90) graphregion(color(white))   mcolor("14 61 136" ) yscale(range(-0.1 0.6)) ///
xtitle(Excluded Region, color(black) size(large)) xscale(titlegap(3)) ytitle(Coef. and 90% CI, color(black) size(large)) title(Regional Elections, color(black) size(large) ) saving(graphics/leaveout2, replace)
                                                            
graph combine "graphics/leaveout1" "graphics/leaveout2" , title("", color(black)) scheme(s2mono) graphregion(color(white))  ycommon rows(2) 


graph export "graphics/FigureA8.png", width(3500) replace
window manage  close graph _all	 

estimates drop _all                         


****************************************************************************************************************************
*Selection on observables Altonji and Oster , compare Nunn and Wantchekon (2011)
****************************************************************************************************************************
use "combined_data_cleaned3.dta", clear


matrix input A=(0,0,0,0,0 \ 0,0,0,0 ,0 \ 0,0,0 ,0,0\ 0,0,0,0,0)
*************country + year dummies vs. all wo ttrend
 local no=1
ivreg2 votes gdp_ratio2 i.panel , cluster(regio) //enep=0 so that R comparable
scalar B1_l=_b[gdp_ratio2]
ivreg2 votes gdp_ratio2 pop enep i.time#c.lang i.elec_year  i.panel , cluster(regio) 
scalar B1_f=_b[gdp_ratio2]
scalar ratio=B1_f/(B1_l-B1_f)
matrix A[`no',3]=abs(B1_f/(B1_l-B1_f))
matrix A[`no',1]=abs(B1_l)
matrix A[`no',2]=abs(B1_f)
*Oster
*Only one control
ivreg2 votes gdp_ratio2 i.panel, cluster(regio) 
 scalar Rmin=e(r2)
 scalar Betamin=_b[gdp_ratio2]
ivreg2 votes gdp_ratio2 pop enep i.time#c.lang i.elec_year  i.panel if enep!=., cluster(regio) 	 
scalar RMAX=min(1,2.2*e(r2))
scalar Rtilda=e(r2)
scalar Betatilda=_b[gdp_ratio2]
scalar deltaOster=1
scalar BetaIden1=Betatilda-deltaOster*(Betamin-Betatilda)*(RMAX-Rtilda)/(Rtilda-Rmin)
estadd scalar BetaIden1
matrix A[`no',4]=abs(BetaIden1)
matrix A[`no',5]=abs(Betamin)
mat list A

matrix B = A[1,1..5]
mat list B
matrix rownames B =  "1"

estout matrix(B, fmt(%9.2f ) )using "tables\TableA8.txt",replace    collabels(b1u b1r ratio) ///
style(tab) delimiter(_tab ) title()  ///
labcol2("(gdp_ratio panel_fe) vs (gdp_ratio panel_fe controls year_fe)" )
 

 exit
 



